import { select, json, tsv, event, zoom, geoPath, geoNaturalEarth1 } from 'd3';
import { feature } from 'topojson';

const svg = select("svg");
const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append("g");

g.append("path")
	.attr("class", "sphere")
	.attr("d", pathGenerator({type:'Sphere'}));

svg.call(
  zoom().on("zoom",()=>{
		g.attr("transform", event.transform);
	})
); 

Promise.all([
  tsv("https://unpkg.com/world-atlas@1.1.4/world/50m.tsv"),
  json('https://unpkg.com/world-atlas@1/world/50m.json')
]).then(([tsvData,topoJSONData])=>{
  
  	const countryNames = tsvData.reduce((a,d)=>{
      a[d.iso_n3] = d.name;
      return a;
    },{});
  
  	const countries = feature(topoJSONData, topoJSONData.objects.countries);
    g.selectAll("path").data(countries.features)
      .enter().append("path")
        .attr("d", pathGenerator)
        .attr("class", "country")
      .append("title")
        .text(d=>countryNames[d.id]);
});